<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdFemCreateFromShape</name>
    <message>
      <location filename="../../Command.cpp" line="+50"/>
      <source>Fem</source>
      <translation>Fem</translation>
    </message>
    <message>
      <source>Create FEM mesh</source>
      <translation>Crea una mesh FEM</translation>
    </message>
    <message>
      <source>Create FEM mesh from shape</source>
      <translation>Crea una mesh FEM da una forma</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+38"/>
      <source>FEM</source>
      <translation>FEM</translation>
    </message>
    <message>
      <source>&amp;FEM</source>
      <translation>&amp;FEM</translation>
    </message>
  </context>
</TS>
